"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const schematics_1 = require("@angular-devkit/schematics");
const tasks_1 = require("@angular-devkit/schematics/tasks");
const dependencies_1 = require("../utility/dependencies");
const versions_1 = require("./versions");
const config_1 = require("@schematics/angular/utility/config");
const ng_ast_utils_1 = require("@schematics/angular/utility/ng-ast-utils");
const custom_1 = require("../utility/custom");
const ast_utils_1 = require("@schematics/angular/utility/ast-utils");
const change_1 = require("@schematics/angular/utility/change");
const cheerio = require("cheerio");
// You don't have to export the function as default. You can also have more than one rule factory
// per file.
function spinner(_options) {
    return (tree, _context) => {
        return schematics_1.chain([
            updateDependencies(),
            addModule(_options.project),
            addComponent()
        ])(tree, _context);
    };
}
exports.spinner = spinner;
function addComponent() {
    return (tree) => {
        const filePath = "./src/app/app.component.html";
        const content = tree.read(filePath);
        let strContent = "";
        if (content)
            strContent = content.toString("utf8");
        const $ = cheerio.load(strContent, {
            lowerCaseTags: true
        });
        const contentToInsert = `
    <ngx-spinner bdColor = "rgba(51, 51, 51, 0.8)"
    size = "medium"
    color = "#01afec"
    type = "ball-clip-rotate"></ngx-spinner>`;
        $.root().append(contentToInsert);
        tree.overwrite(filePath, $.html());
        return tree;
    };
}
function updateDependencies() {
    return (tree, context) => {
        context.logger.debug("Updating dependencies...");
        context.addTask(new tasks_1.NodePackageInstallTask());
        dependencies_1.addPackageJsonDependency(tree, {
            type: dependencies_1.NodeDependencyType.Default,
            name: "ngx-spinner",
            version: versions_1.ngxSpinnerVersion
        });
        return tree;
    };
}
function addModule(projectName) {
    return (tree) => {
        const workspace = config_1.getWorkspace(tree);
        const project = workspace.projects[projectName || workspace.defaultProject];
        const buildOptions = custom_1.getProjectTargetOptions(project, "build");
        const modulePath = ng_ast_utils_1.getAppModulePath(tree, buildOptions.main);
        const moduleSource = custom_1.getSourceFile(tree, modulePath);
        const changes = ast_utils_1.addImportToModule(moduleSource, modulePath, "NgxSpinnerModule", "ngx-spinner");
        const recorder = tree.beginUpdate(modulePath);
        changes.forEach(change => {
            if (change instanceof change_1.InsertChange) {
                recorder.insertLeft(change.pos, change.toAdd);
            }
        });
        tree.commitUpdate(recorder);
        return tree;
    };
}
//# sourceMappingURL=index.js.map